Module event_loop

Module event_loop 

Structs

EventLoop
The main structure for the event loop, holding its configuration.
EventLoopBuilder
Builder pattern for constructing an EventLoop.
EventLoopConfig
Configuration for the event loop, specifying the frames per second (fps).