pub fn set_hover(fade: &Fade, hovered: bool, reduced: bool)Expand description
Record a hover flip for fade (reduced motion snaps). Prefer
hover_listener, which also asks the clock for the frames to paint it.
pub fn set_hover(fade: &Fade, hovered: bool, reduced: bool)Record a hover flip for fade (reduced motion snaps). Prefer
hover_listener, which also asks the clock for the frames to paint it.