Structs
- Event
Loop - The main structure for the event loop, holding its configuration.
- Event
Loop Builder - Builder pattern for constructing an
EventLoop. - Event
Loop Config - Configuration for the event loop, specifying the frames per second (fps).
EventLoop.